diff --git a/core/lib/Drupal/Core/Updater/Theme.php b/core/lib/Drupal/Core/Updater/Theme.php
index 7ac70f0..115844f 100644
--- a/core/lib/Drupal/Core/Updater/Theme.php
+++ b/core/lib/Drupal/Core/Updater/Theme.php
@@ -101,7 +101,7 @@ public function postInstallTasks() {
     return [
       $default_options + [
         '#url' => Url::fromRoute('system.themes_page'),
-        '#title' => t('Install newly added themes'),
+        '#title' => t('Enable newly added themes'),
       ],
       $default_options + [
         '#url' => Url::fromRoute('system.admin'),
diff --git a/core/modules/system/src/Controller/SystemController.php b/core/modules/system/src/Controller/SystemController.php
index 4af1dcb..0971238 100644
--- a/core/modules/system/src/Controller/SystemController.php
+++ b/core/modules/system/src/Controller/SystemController.php
@@ -258,10 +258,10 @@ public function themesPage() {
             }
             if ($theme_uninstallable) {
               $theme->operations[] = [
-                'title' => $this->t('Uninstall'),
+                'title' => $this->t('Disable'),
                 'url' => Url::fromRoute('system.theme_uninstall'),
                 'query' => $query,
-                'attributes' => ['title' => $this->t('Uninstall @theme theme', ['@theme' => $theme->info['name']])],
+                'attributes' => ['title' => $this->t('Disable @theme theme', ['@theme' => $theme->info['name']])],
               ];
             }
             $theme->operations[] = [
@@ -275,16 +275,16 @@ public function themesPage() {
         }
         else {
           $theme->operations[] = [
-            'title' => $this->t('Install'),
+            'title' => $this->t('Enable'),
             'url' => Url::fromRoute('system.theme_install'),
             'query' => $query,
-            'attributes' => ['title' => $this->t('Install @theme theme', ['@theme' => $theme->info['name']])],
+            'attributes' => ['title' => $this->t('Enable @theme theme', ['@theme' => $theme->info['name']])],
           ];
           $theme->operations[] = [
-            'title' => $this->t('Install and set as default'),
+            'title' => $this->t('Enable and set as default'),
             'url' => Url::fromRoute('system.theme_set_default'),
             'query' => $query,
-            'attributes' => ['title' => $this->t('Install @theme as default theme', ['@theme' => $theme->info['name']])],
+            'attributes' => ['title' => $this->t('Enable @theme as default theme', ['@theme' => $theme->info['name']])],
           ];
         }
       }
diff --git a/core/modules/config_translation/src/Tests/ConfigTranslationUiThemeTest.php b/core/modules/config_translation/src/Tests/ConfigTranslationUiThemeTest.php
index 53713a9..7e69be8 100644
--- a/core/modules/config_translation/src/Tests/ConfigTranslationUiThemeTest.php
+++ b/core/modules/config_translation/src/Tests/ConfigTranslationUiThemeTest.php
@@ -55,14 +55,14 @@ protected function setUp() {
    * Tests that theme provided *.config_translation.yml files are found.
    */
   public function testThemeDiscovery() {
     // Install the test theme and rebuild routes.
     $theme = 'config_translation_test_theme';
 
     $this->drupalLogin($this->adminUser);
 
     $this->drupalGet('admin/appearance');
     $elements = $this->xpath('//a[normalize-space()=:label and contains(@href, :theme)]', [
-      ':label' => 'Install and set as default',
+      ':label' => 'Enable and set as default',
       ':theme' => $theme,
     ]);
     $this->drupalGet($GLOBALS['base_root'] . $elements[0]['href'], ['external' => TRUE]);
@@ -55,14 +55,14 @@ protected function setUp() {
    */
   public function testThemeDiscovery() {
-    // Install the test theme and rebuild routes.
+    // Enable the test theme and rebuild routes.
     $theme = 'config_translation_test_theme';
 
diff --git a/core/modules/system/src/Tests/System/ThemeTest.php b/core/modules/system/src/Tests/System/ThemeTest.php
index 29d88a3..cbb5425 100644
--- a/core/modules/system/src/Tests/System/ThemeTest.php
+++ b/core/modules/system/src/Tests/System/ThemeTest.php
@@ -378,8 +378,8 @@ public function testUninstallingThemes() {
     ];
     $this->drupalPostForm('admin/appearance', $edit, t('Save configuration'));
 
-    // Check that seven can be uninstalled now.
-    $this->assertRaw('Uninstall Seven theme', 'A link to uninstall the Seven theme does appear on the theme settings page.');
+    // Check that seven can be disabled now.
+    $this->assertRaw('Disable Seven theme', 'A link to Disable the Seven theme does appear on the theme settings page.');
     // Check that the classy theme still cannot be uninstalled as it is a
     // base theme of bartik.
     $this->assertNoRaw('Uninstall Classy theme', 'A link to uninstall the Classy theme does not appear on the theme settings page.');
@@ -387,18 +387,18 @@ public function testUninstallingThemes() {
     // Change the default theme to stark, stark is second in the list.
     $this->clickLink(t('Set as default'), 1);
 
-    // Check that bartik can be uninstalled now.
-    $this->assertRaw('Uninstall Bartik theme', 'A link to uninstall the Bartik theme does appear on the theme settings page.');
+    // Check that bartik can be disabled now.
+    $this->assertRaw('Disable Bartik theme', 'A link to uninstall the Bartik theme does appear on the theme settings page.');
 
     // Check that the classy theme still can't be uninstalled as neither of it's
     // base themes have been.
     $this->assertNoRaw('Uninstall Classy theme', 'A link to uninstall the Classy theme does not appear on the theme settings page.');
 
-    // Uninstall each of the three themes starting with Bartik.
-    $this->clickLink(t('Uninstall'));
+    // Disable each of the three themes starting with Bartik.
+    $this->clickLink(t('Disable'));
     $this->assertRaw('The <em class="placeholder">Bartik</em> theme has been uninstalled');
     // Seven is the second in the list.
-    $this->clickLink(t('Uninstall'));
+    $this->clickLink(t('Disable'));
     $this->assertRaw('The <em class="placeholder">Seven</em> theme has been uninstalled');
 
     // Check that the classy theme still can't be uninstalled as it is hidden.
@@ -410,9 +410,9 @@ public function testUninstallingThemes() {
    */
   public function testInstallAndSetAsDefault() {
     $this->drupalGet('admin/appearance');
     // Bartik is uninstalled in the test profile and has the third "Install and
     // set as default" link.
-    $this->clickLink(t('Install and set as default'), 2);
+    $this->clickLink(t('Enable and set as default'), 2);
     // Test the confirmation message.
     $this->assertText('Bartik is now the default theme.');
     // Make sure Bartik is now set as the default theme in config.
@@ -410,9 +410,9 @@ public function testUninstallingThemes() {
   public function testInstallAndSetAsDefault() {
     $this->drupalGet('admin/appearance');
-    // Bartik is uninstalled in the test profile and has the third "Install and
+    // Bartik is uninstalled in the test profile and has the third "Enable and
     // set as default" link.
